@@ -35,7 +35,7 @@ use Class::Struct
 
 use Carp qw/croak/;
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 
 sub _sort_by_option_priority_desc {
@@ -187,7 +187,6 @@ sub exec {
 
 sub _inventory_condition_tofire {
   my $self = shift;
-  my $nbConditionOK = 0;
   my $nbNewTopics = 0;
   my $ncb = $self->ncb;
   my $prioritized_cbp = $self->prioritized_cb;
@@ -205,7 +204,7 @@ sub _inventory_condition_tofire {
   foreach (my $i = 0; $i < $ncb; $i++) {
     my $cb = $prioritized_cbp->[$i];
     my $option = $cache ? $cacheOptionp->[$i] : $cb->option;
-    my $conditionMode = $cache ? $cacheOptionConditionModep->[$i] : $option->conditionMode;
+    my $conditionMode = (($cache ? $cacheOptionConditionModep->[$i] : $option->conditionMode) eq 'and') ? 1 : 0;
 
     my @condition = ();
     my $description = $cache ? $cacheCbDescriptionp->[$i] : $cb->description;
@@ -214,6 +213,9 @@ sub _inventory_condition_tofire {
 	if (ref($coderef) eq 'CODE') {
 	    push(@condition, &$coderef($cb, $self, $selfArguments, @arguments) ? 1 :0);
 	} elsif (defined($description)) {
+	    #
+	    # Per def condition is the string 'auto'
+	    #
 	    push(@condition, (grep {$_ eq $description} @{$selfArguments}) ? 1 :0);
 	}
     }
@@ -224,11 +226,17 @@ sub _inventory_condition_tofire {
     my $condition = 0;
     if (@condition) {
       $condition = shift(@condition);
-      if ($conditionMode eq 'and') {
+      if ($conditionMode) {
+	  #
+	  # Per def, this is 'and'
+	  #
         foreach (@condition) {
           $condition &&= $_;
         }
-      } elsif ($conditionMode eq 'or') {
+      } else {
+	  #
+	  # Per def, this is 'or'
+	  #
         foreach (@condition) {
           $condition ||= $_;
         }
@@ -251,7 +259,6 @@ sub _inventory_condition_tofire {
           }
         }
       }
-      ++$nbConditionOK;
     } else {
       if (@condition) {
         $prioritized_cb_tofirep->[$i] = -1;
@@ -357,6 +364,9 @@ sub _fire {
 	if (ref($method) eq 'CODE') {
 	    @rc = &$method($cb, $self, $selfArguments, @arguments);
 	} else {
+	    #
+	    # Per def method is the string 'auto'
+	    #
 	    @rc = $self->topic_fired_data($cb->description) || [];
 	}
       }
@@ -443,20 +453,12 @@ sub _inventory_initialize_topic {
 
 sub _inventory_initialize_tofire {
   my $self = shift;
-  my $prioritized_cb_tofirep = $self->prioritized_cb_tofire;
-  my $ncb = $self->ncb;
-  foreach (my $i = 0; $i < $ncb; $i++) {
-      $prioritized_cb_tofirep->[$i] = 0;
-  }
+  $self->prioritized_cb_tofire([ (0) x $self->ncb ]);
 }
 
 sub _inventory_initialize_fired {
   my $self = shift;
-  my $prioritized_cb_firedp = $self->prioritized_cb_fired;
-  my $ncb = $self->ncb;
-  foreach (my $i = 0; $i < $ncb; $i++) {
-      $prioritized_cb_firedp->[$i] = 0;
-  }
+  $self->prioritized_cb_fired([ (0) x $self->ncb ]);
 }
 
 sub _inventory_fire {
@@ -663,7 +665,7 @@ MarpaX::Languages::C::AST::Callback - Simple but powerful callback generic frame
 
 =head1 VERSION
 
-version 0.17
+version 0.19
 
 =head1 DESCRIPTION
 
