@@ -15,7 +15,7 @@ use constant LHS_PROCESS_EVENT => '<process>';
 use constant CLOSEANYSCOPE_PRIORITY => -1000;
 use constant RESETANYDATA_PRIORITY => -2000;
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 
 sub new {
@@ -423,7 +423,7 @@ sub _reset_helper {
     return @rc;
 }
 # ----------------------------------------------------------------------------------------
-sub _collect_helper {
+sub _collect_and_reset_helper {
     my ($method, $callback, $eventsp, @topics) = @_;
 
     my @rc = ();
@@ -530,9 +530,9 @@ sub _register_rule_callbacks {
       } else {
         ($name, $value) = ($_, undef);
       }
-	my $event = $name . '$';
-	++$genomeEvents{$event};
-	++$rshProcessEvents{$event};
+      my $event = $name . '$';
+      ++$genomeEvents{$event};
+      ++$rshProcessEvents{$event};
       $genomeEventValues{$event} = $value;
     }
   }
@@ -583,6 +583,7 @@ sub _register_rule_callbacks {
     }
     #
     # rhs$ event will collect into rhs$ topic all Gx$ topics (created automatically if needed)
+    # and reset them
     #
     my $event = $rhs . '$';
     ++$rshProcessEvents{$event};
@@ -590,7 +591,7 @@ sub _register_rule_callbacks {
 			(
 			 description => $event,
                          extra_description => "$event [process] ",
-			 method =>  [ \&_collect_helper, keys %genomeTopicsNotToUpdate ],
+			 method =>  [ \&_collect_and_reset_helper, keys %genomeTopicsNotToUpdate ],
 			 method_mode => 'push',
 			 option => MarpaX::Languages::C::AST::Callback::Option->new
 			 (
@@ -602,25 +603,6 @@ sub _register_rule_callbacks {
 			 )
 			)
 	);
-    #
-    ## .. and reset them
-    #
-    $callback->register(MarpaX::Languages::C::AST::Callback::Method->new
-			(
-			 description => $event,
-                         extra_description => "$event [reset] ",
-			 method =>  [ \&_reset_helper, keys %genomeTopicsToUpdate ],
-			 method_mode => 'replace',
-			 option => MarpaX::Languages::C::AST::Callback::Option->new
-			 (
-			  condition => [ [ 'auto' ] ],  # == match on description
-			  topic => {%genomeTopicsToUpdate},
-			  topic_persistence => 'level',
-			  priority => 0,
-			 )
-			)
-	);
-
   }
 
   #
@@ -706,23 +688,6 @@ sub _register_rule_callbacks {
                    )
                   )
                  );
-  #  $self->register(MarpaX::Languages::C::AST::Callback::Method->new
-  #                 (
-  #                  description => $lhsResetEvent,
-  #                  method => [ \&_subFire, $hashp->{lhs}, $callback, \%lhsResetEvents, {$hashp->{lhs} . '$' => $lhsResetEvent, 'translationUnit$' => $lhsResetEvent} ],
-  #                  option => MarpaX::Languages::C::AST::Callback::Option->new
-  #                  (
-  #                   condition => [
-  #                                 [ sub { my ($method, $callback, $eventsp, $processEventsp) = @_;
-  #                                         return grep {exists($processEventsp->{$_})} @{$eventsp};
-  #                                       },
-  #                                   \%lhsResetEvents
-  #                                 ]
-  #                                ],
-  #                   priority => $hashp->{reset_priority}
-  #                  )
-  #                 )
-  #                );
 
   return $callback;
 }
@@ -741,7 +706,7 @@ MarpaX::Languages::C::AST::Callback::Events - Events callback when translating a
 
 =head1 VERSION
 
-version 0.17
+version 0.19
 
 =head1 DESCRIPTION
 
