@@ -7,7 +7,7 @@ use Carp qw/croak/;
 
 # ABSTRACT: ISO ANSI C 2011 grammar written in Marpa BNF
 
-our $VERSION = '0.17'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 
 our %DEFAULT_PAUSE = (
@@ -91,7 +91,7 @@ MarpaX::Languages::C::AST::Grammar::ISO_ANSI_C_2011 - ISO ANSI C 2011 grammar wr
 
 =head1 VERSION
 
-version 0.17
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -199,8 +199,10 @@ enumerationConstantIdentifier  # before it has been defined as such
 enumerationConstant            # before it has been defined as such
 	::= enumerationConstantIdentifier
 
+stringLiteral ::= STRING_LITERAL_UNIT+
+
 string
-	::= STRING_LITERAL
+	::= stringLiteral
 	| FUNC_NAME
 
 genericSelection
@@ -349,7 +351,6 @@ declarationCheckdeclarationSpecifiers ::= declarationSpecifiers action => deref
 event 'declarationCheckinitDeclaratorList$' = completed <declarationCheckinitDeclaratorList>
 declarationCheckinitDeclaratorList    ::= initDeclaratorList    action => deref
 
-event '^declarationCheck' = predicted <declarationCheck>
 event 'declarationCheck$' = completed <declarationCheck>
 declarationCheck ::= declarationCheckdeclarationSpecifiers declarationCheckinitDeclaratorList SEMICOLON action => deref
 
@@ -568,7 +569,6 @@ parameterList
 event 'parameterDeclarationdeclarationSpecifiers$' = completed <parameterDeclarationdeclarationSpecifiers>
 parameterDeclarationdeclarationSpecifiers ::= declarationSpecifiers action => deref
 
-event '^parameterDeclarationCheck' = predicted <parameterDeclarationCheck>
 event 'parameterDeclarationCheck$' = completed <parameterDeclarationCheck>
 parameterDeclarationCheck ::= parameterDeclarationdeclarationSpecifiers declarator action => deref
 
@@ -641,7 +641,7 @@ designator
         | LBRACKET constantExpression ELLIPSIS constantExpression RBRACKET # GCC Extension
 
 staticAssertDeclaration
-	::= STATIC_ASSERT LPAREN constantExpression COMMA STRING_LITERAL RPAREN SEMICOLON
+	::= STATIC_ASSERT LPAREN constantExpression COMMA stringLiteral RPAREN SEMICOLON
 
 statement
 	::= labeledStatement
@@ -714,11 +714,9 @@ functionDefinition
 event 'fileScopeDeclarator$' = completed <fileScopeDeclarator>
 fileScopeDeclarator ::= declarator action => deref_and_bless_declarator
 
-event '^functionDefinitionCheck1' = predicted <functionDefinitionCheck1>
 event 'functionDefinitionCheck1$' = completed <functionDefinitionCheck1>
 functionDefinitionCheck1 ::= functionDefinitionCheck1declarationSpecifiers fileScopeDeclarator functionDefinitionCheck1declarationList compoundStatementReenterScope action => deref
 
-event '^functionDefinitionCheck2' = predicted <functionDefinitionCheck2>
 event 'functionDefinitionCheck2$' = completed <functionDefinitionCheck2>
 functionDefinitionCheck2 ::= functionDefinitionCheck2declarationSpecifiers fileScopeDeclarator                                         compoundStatementReenterScope action => deref
 
@@ -925,9 +923,11 @@ F_CONSTANT ~ D_many E FS_maybe
            | HP H_any '.' H_many P FS_maybe
            | HP H_many '.' P FS_maybe
 
-:lexeme ~ <STRING_LITERAL>         priority => -103
-STRING_LITERAL ~ STRING_LITERAL_UNIT+
-
+:lexeme ~ <STRING_LITERAL_UNIT>    priority => -103
+STRING_LITERAL_INSIDE ~ [^"\\\n]
+STRING_LITERAL_INSIDE ~ ES
+STRING_LITERAL_INSIDE_any ~ STRING_LITERAL_INSIDE*
+STRING_LITERAL_UNIT ~ SP_maybe '"' STRING_LITERAL_INSIDE_any '"' WS_any
 :lexeme ~ <ELLIPSIS>      priority => -104
 ELLIPSIS     ~ '...'
 :lexeme ~ <RIGHT_ASSIGN>  priority => -105
@@ -1064,10 +1064,6 @@ QUOTE     ~ [']
 I_CONSTANT_INSIDE ~ [^'\\\n]
 I_CONSTANT_INSIDE ~ ES
 I_CONSTANT_INSIDE_many ~ I_CONSTANT_INSIDE+
-STRING_LITERAL_INSIDE ~ [^"\\\n]
-STRING_LITERAL_INSIDE ~ ES
-STRING_LITERAL_INSIDE_any ~ STRING_LITERAL_INSIDE*
-STRING_LITERAL_UNIT ~ SP_maybe '"' STRING_LITERAL_INSIDE_any '"' WS_any
 BS         ~ '\'
 ANYTHING_ELSE   ~ [.]
 
